.. include:: ../../README.rst

.. toctree::
   :maxdepth: 2

   examples
   example-jobs
   example-templates
   example-roles
   example-autodoc

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
